abacusai.tone_details — AbacusAI documentation

# abacusai.tone_details

## Classes

`ToneDetails` | Tone details for audio

## Module Contents

class abacusai.tone_details.ToneDetails(client, voiceId=None, name=None, gender=None, language=None, age=None, accent=None, useCase=None, description=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Tone details for audio

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - voiceId (str) – The voice id

    - name (str) – The name

    - gender (str) – The gender

    - language (str) – The language

    - age (str) – The age

    - accent (str) – The accent

    - useCase (str) – The use case

    - description (str) – The description

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict